package owl

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Owl_dense_ndarray_intf.ComplexSource

Sourcetype elt
Sourcetype arr
Sourcetype cast_arr
Complex operations
Sourceval complex : cast_arr -> cast_arr -> arr

complex re im constructs a complex ndarray/matrix from re and im. re and im contain the real and imaginary part of x respectively.

Note that both re and im can be complex but must have same type. The real part of re will be the real part of x and the imaginary part of im will be the imaginary part of x.

Sourceval polar : cast_arr -> cast_arr -> arr

polar rho theta constructs a complex ndarray/matrix from polar coordinates rho and theta. rho contains the magnitudes and theta contains phase angles. Note that the behaviour is undefined if rho has negative elelments or theta has infinity elelments.

Sourceval re : arr -> cast_arr
Sourceval im : arr -> cast_arr
Sourceval sum' : arr -> elt