package owl

  1. Overview
  2. Docs
On This Page
  1. Core functions
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Sig.OptimiseSource

Sourcemodule Utils : sig ... end

Utils module

Sourcemodule Learning_Rate : sig ... end

Strategies for learning rate update

Sourcemodule Batch : sig ... end

Batch module

Sourcemodule Loss : sig ... end

Loss module

Sourcemodule Gradient : sig ... end

Gradient module

Sourcemodule Momentum : sig ... end

Momentum module

Sourcemodule Regularisation : sig ... end

Regularisation module

Sourcemodule Clipping : sig ... end

Clipping module

Sourcemodule Stopping : sig ... end

Stopping module

Sourcemodule Checkpoint : sig ... end

Checkpoint module

Sourcemodule Params : sig ... end

Params module

Core functions

This function minimises the weight w of passed-in function f.

* f is a function f : w -> x -> y. * w is a row vector but y can have any shape.

Sourceval minimise_network : ?state:Checkpoint.state -> Params.typ -> (Algodiff.t -> Algodiff.t * Algodiff.t array array) -> (Algodiff.t -> Algodiff.t array array * Algodiff.t array array) -> (Algodiff.t array array -> unit) -> (string -> unit) -> Algodiff.t -> Algodiff.t -> Checkpoint.state

This function is specifically designed for minimising the weights in a neural network of graph structure. In Owl's earlier versions, the functions in the regression module were actually implemented using this function.

This function minimises f : x -> y w.r.t x.

x is an ndarray; and y is an scalar value.

Sourceval minimise_compiled_network : ?state:Checkpoint.state -> Params.typ -> (Algodiff.t -> Algodiff.t -> Algodiff.t) -> (unit -> unit) -> (string -> unit) -> Algodiff.t -> Algodiff.t -> Checkpoint.state

TODO